twall package
=============

This is the top-level package that contains the API for launching both the console version and the web version of
the application.


Subpackages
-----------

.. toctree::

    twall.console
    twall.twitter
    twall.web

Module contents
---------------

.. automodule:: twall
    :members:
    :undoc-members:
    :show-inheritance:
